<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdRaytracingExportProject</name>
    <message>
      <location filename="../../Command.cpp" line="+452"/>
      <source>File</source>
      <translation>File</translation>
    </message>
    <message>
      <source>&amp;Export project...</source>
      <translation>&amp;Esporta progetto...</translation>
    </message>
    <message>
      <source>Export the Povray project file</source>
      <translation>Esporta il file di progetto Povray</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPartSegment</name>
    <message>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <source>Insert part</source>
      <translation>Inserisci parte</translation>
    </message>
    <message>
      <source>Insert a new part object into a Povray project</source>
      <translation>Inserisci un nuovo oggetto parte in un progetto Povray</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPovrayProject</name>
    <message>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <source>New Povray project</source>
      <translation>Nuovo progetto Povray</translation>
    </message>
    <message>
      <source>Insert new Povray project into the document</source>
      <translation>Inserisce un nuovo progetto Povray nel documento</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteCamera</name>
    <message>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <source>Export camera to povray...</source>
      <translation>Esporta la camera a povray...</translation>
    </message>
    <message>
      <source>Export the camera positon of the active 3D view in PovRay format to a file</source>
      <translation>Esporta la posizione della telecamera della vista 3D attiva in un file in formato PovRay</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWritePart</name>
    <message>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <source>Export part to povray...</source>
      <translation>Esporta la parte in povray...</translation>
    </message>
    <message>
      <source>Write the selected Part (object) as a povray file</source>
      <translation>Scrive la parte selezionata (oggetto) come un file povray</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteView</name>
    <message>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <source>Export view to povray...</source>
      <translation>Esporta la vista in povray...</translation>
    </message>
    <message>
      <source>Write the active 3D view with camera and all its content to a povray file</source>
      <translation>Salva la vista 3D attiva con la camera e tutto il suo contenuto in un file povray</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Povray(*.pov)</source>
      <translation>Povray (*.pov)</translation>
    </message>
    <message>
      <source>All Files (*.*)</source>
      <translation>Tutti i file (*.*)</translation>
    </message>
    <message>
      <source>Export page</source>
      <translation>Esporta pagina</translation>
    </message>
    <message>
      <source>Wrong selection</source>
      <translation>Selezione errata</translation>
    </message>
    <message>
      <source>Select a Part object.</source>
      <translation>Seleziona un oggetto Part.</translation>
    </message>
    <message>
      <source>No Povray project to insert</source>
      <translation>Nessun progetto Povray da inserire</translation>
    </message>
    <message>
      <source>Create a Povray project to insert a view.</source>
      <translation>Crea un progetto Povray per inserire una vista.</translation>
    </message>
    <message>
      <source>Select one Povray project object.</source>
      <translation>Seleziona un progetto Povray.</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRay</name>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="+16"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <source>Directories</source>
      <translation>Cartelle</translation>
    </message>
    <message>
      <source>Default Project dir:</source>
      <translation>Cartella di default del progetto:</translation>
    </message>
    <message>
      <source>Camera file name:</source>
      <translation>Nome del file della telecamera:</translation>
    </message>
    <message>
      <source>Part file name:</source>
      <translation>Nome del file della parte:</translation>
    </message>
    <message>
      <source>TempCamera.inc</source>
      <translation>TempCamera.inc</translation>
    </message>
    <message>
      <source>TempPart.inc</source>
      <translation>TempPart.inc</translation>
    </message>
    <message>
      <source>Mesh export settings</source>
      <translation>Impostazioni di esportazione mesh</translation>
    </message>
    <message>
      <source>max mesh deviation:</source>
      <translation>Massima deviazione della mesh:</translation>
    </message>
    <message>
      <source>Do not calculate vertex normals</source>
      <translation>Non calcolare le normali ai vertici</translation>
    </message>
    <message>
      <source>Write u,v coordinates</source>
      <translation>Salva le coordinate u,v</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
  </context>
</TS>
